@@ -114,6 +114,8 @@ class Subscription(object):
                 fut = asyncio.run_coroutine_threadsafe(self._cbk(msg, syn), self._loop)
                 # XXX NOTFOUND here?
                 result = fut.result()
+            except concurrent.futures.CancelledError:  # eventloop shutdown
+                return
             except Exception as e:
                 print('Error calling callback: {}'.format(e))
                 traceback.print_tb(e.__traceback__)
