@@ -41,7 +41,7 @@ def _py_result(model, r, del_uuid):
                 v = v.ToNanoseconds() / 1000000000
             fields[f] = v
         uuid = fields.get('uuid')
-        if uuid:
+        if uuid and model.cache_enabled:
             # handle this as a managed object
             cur = model._objs.get(uuid)
             if cur:
@@ -164,9 +164,10 @@ class BaseModelObject:
 
 class PreseemModel:
     """API to the Preseem Data Model."""
-    def __init__(self, client):
+    def __init__(self, client, cache=False):
         """Initialize the model with a GRPC client."""
         self._client = client
+        self.cache_enabled = cache  # See STM-9547
         self._objs = {}
         self._types = {}
 
